//Version: 1.2
using System;
using System.Data;
using System.Windows.Forms;
using System.Drawing;
using System.IO;

namespace WebBrowser //The namespace name is not important.
{

	//Inherit from IDisposable if you need Basic4ppc to free resources when the application is closed.
	public class WebBrowser:IDisposable 
	{
        // autoscale fields
        public static object B4P_AutoScale = null;

        // private variables
        private System.Windows.Forms.WebBrowser wb; //The "real" object.
        private object[] eventObject; //One object[] for each event (one event here).
        private string NavURL = "";
        private bool CancelNav = false;
	
        // public events
        public event EventHandler DocumentCompleted; //The event handler name must match the event name.
        public event EventHandler GotFocus;
        public event EventHandler LostFocus;
        public event EventHandler Navigated;
        public event EventHandler Navigating;
        //public event EventHandler Validated;
        //public event EventHandler Validating; 

//http://msdn2.microsoft.com/en-us/library/ms229657(VS.80).aspx   
    
//The following considerations apply only to Windows Mobile 2003 for Pocket PC and Windows Mobile 2003 for Smartphone:

//The Refresh method throws a NotSupportedException exception.

//Because the WebBrowser control can contain subcontrols embedded in the HTML form,
//you cannot determine if the WebBrowser control has the focus by monitoring the GotFocus event. 
//As a workaround, use a process of elimination of other controls that might have the focus. 

//The Url property is not set in WebBrowserNavigatingEventArgs and returns an empty string.

//On a device other than a Pocket PC or Smartphone that is running Microsoft Windows CE 5.0,
//the Navigated and DocumentCompleted events both occur twice when a new URL is visited. This error is planned to be fixed in future releases of Windows CE. 

		
		//constructor
		public WebBrowser (Control FormName, int Left, int Top, int Width, int Height)
		{

            wb = new System.Windows.Forms.WebBrowser();
			wb.Left = Left;
			wb.Top = Top;
			wb.Width = Width;
			wb.Height = Height;
			FormName.Controls.Add(wb);
			eventObject = new object[] {this," "}; //This is the object that will pass with the event.

            wb.DocumentCompleted += DocumentCompletedEvent;
            wb.GotFocus += GotFocusEvent;
            wb.LostFocus += LostFocusEvent;
            wb.Navigated += NavigatedEvent;
            wb.Navigating += NavigatingEvent;
            //wb.Validated += ValidatedEvent;
            //wb.Validating += ValidatingEvent;
        }

        //properties

        // 1.2 added Refresh, AutoScale, BringToFront and Focus
		public double DLLVersion
		{get {return 1.2;}}

        public bool CancelNavigate
        { set { CancelNav = value; } }

		public Control ControlRef
		{get {return wb;}}

        public String DocumentText
        { set { wb.DocumentText = value; } }

        public int Height
        { get { return wb.Height; } set { wb.Height = value; } }

        public bool IsBusy
        { get { return wb.IsBusy; } }

        public bool IsOffline
        { get { return wb.IsOffline; }  }

        public string NavigatingURL
        { get { return NavURL; }  }

        public String URL
        {get {return wb.Url.ToString();} set {wb.Url =  new Uri(value);}}
        
        public int Width
		{get {return wb.Width;} set {wb.Width = value;}}

        public int Left
        { get { return wb.Left; } set { wb.Left = value; } }

        public int Top
		{get {return wb.Top;} set {wb.Top = value;}}

		public bool Visible
		{get {return wb.Visible;} set {wb.Visible = value;}}


        //methods

        public void Navigate(String UrlStr)
        {
            wb.Navigate(new Uri(UrlStr));
        }

        public void BringToFront()
        {
            wb.BringToFront();
        }

        public void Focus()
        {
            wb.Focus();
        }

        public void GoBack()
        {
            wb.GoBack();
        }

        public void GoForward()
        {
            wb.GoForward();
        }

        public void Stop()
        {
            wb.Stop();
        }

        public void Refresh()
        {
            wb.Refresh();
        }

        // private event handlers
        private void DocumentCompletedEvent(object sender, EventArgs e)
		{
            if (DocumentCompleted != null) 
			{
                eventObject[1] = "DocumentCompleted";
                this.DocumentCompleted(eventObject, null);
			}
		}

        private void GotFocusEvent(object sender, EventArgs e)
        {
            if (GotFocus != null)
            {
                eventObject[1] = "GotFocus";
                GotFocus(eventObject, null);
            }
        }

        private void LostFocusEvent(object sender, EventArgs e)
        {
            if (LostFocus != null)
            {
                eventObject[1] = "LostFocus";
                LostFocus(eventObject, null);
            }
        }

        private void NavigatedEvent(object sender, EventArgs e)
        {
            if (Navigated != null)
            {
                eventObject[1] = "Navigated";
                Navigated(eventObject, null);
            }
        }

        private void NavigatingEvent(object sender, WebBrowserNavigatingEventArgs e)
        {
            CancelNav = false;
            if (e.Url == null)
            {
                NavURL = "Unavailable on WM2003";
            }
            else
            {
                NavURL = e.Url.ToString();
            }
            if (Navigating != null)
            {
                eventObject[1] = "Navigating";
                Navigating(eventObject, null);
            }
            if (CancelNav)
            {
                e.Cancel = true;
            }
        }

        //private void ValidatedEvent(object sender, EventArgs e)
        //{
        //    if (Validated != null)
        //    {
        //        eventObject[1] = "Validated";
        //        this.Validated(eventObject, null);
        //    }
        //}

        //private void ValidatingEvent(object sender, EventArgs e)
        //{
        //    if (Validating != null)
        //    {
        //        eventObject[1] = "Validating";
        //        this.Validating(eventObject, null);
        //    }
        //}

        public void Dispose()
        {
            DocumentCompleted = null;
            GotFocus = null;
            LostFocus = null;
            Navigated = null;
            Navigating = null;
            //Validated = null;
            //Validating = null;

            wb.DocumentCompleted -= DocumentCompletedEvent;
            wb.GotFocus -= GotFocusEvent;
            wb.LostFocus -= LostFocusEvent;
            wb.Navigated -= NavigatedEvent;
            wb.Navigating -= NavigatingEvent;
            //wb.Validated -= ValidatedEvent;
            //wb.Validating -= ValidatingEvent;

            wb.Dispose();
        }
	}
}
